Revision: 776
http://svn.sourceforge.net/geany/?rev=776&view=rev
Author: eht16
Date: 2006-08-31 11:50:10 -0700 (Thu, 31 Aug 2006)
Log Message:
-----------
Added missing inclusion of vte.h.
Modified Paths:
--------------
trunk/src/document.c
Modified: trunk/src/document.c
===================================================================
--- trunk/src/document.c 2006-08-31 18:25:57 UTC (rev 775)
+++ trunk/src/document.c 2006-08-31 18:50:10 UTC (rev 776)
@@ -56,6 +56,7 @@
#include "encodings.h"
#include "notebook.h"
#include "main.h"
+#include "vte.h"
/* Returns -1 if no text found or the new range endpoint after replacing. */
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
Revision: 775
http://svn.sourceforge.net/geany/?rev=775&view=rev
Author: eht16
Date: 2006-08-31 11:25:57 -0700 (Thu, 31 Aug 2006)
Log Message:
-----------
Improved parsing compiler messages when using the ferite compiler.
Added some primitives and improved compiler settings for Ferite.
Modified Paths:
--------------
trunk/ChangeLog
trunk/data/filetypes.ferite
trunk/src/msgwindow.c
Modified: trunk/ChangeLog
===================================================================
--- trunk/ChangeLog 2006-08-30 18:53:45 UTC (rev 774)
+++ trunk/ChangeLog 2006-08-31 18:25:57 UTC (rev 775)
@@ -1,3 +1,10 @@
+2006-08-31 Enrico Tröger <enrico.troeger(a)uvena.de>
+
+ * src/msgwindow.c, data/filetypes.ferite:
+ Improved parsing compiler messages when using the ferite compiler.
+ Added some primitives and improved compiler settings for Ferite.
+
+
2006-08-30 Enrico Tröger <enrico.troeger(a)uvena.de>
* configure.in, src/callbacks.c, src/geany.h, src/main.c:
Modified: trunk/data/filetypes.ferite
===================================================================
--- trunk/data/filetypes.ferite 2006-08-30 18:53:45 UTC (rev 774)
+++ trunk/data/filetypes.ferite 2006-08-31 18:25:57 UTC (rev 775)
@@ -24,12 +24,12 @@
[keywords]
# all items must be in one line
primary=false null self super true abstract alias arguments attribute_missing break case class closure conformsToProtocol constructor default deliver destructor diliver do else extends final fix for function if iferr implements include instanceof method_missing modifies namespace new private protected protocol public recipient rename return static switch uses using while
-types=string number array object void
-docComment=@brief @class @declaration @description @end @example @extends @function @group @implements @modifies @module @namespace @param @protocol @return @return @static @type @variable @warning
+types=string number array object void XML Unix Sys String Stream Serialize RMI Posix Number Network Math FileSystem Console Array
+docComment=brief class declaration description end example extends function group implements modifies module namespace param protocol return return static type variable warning
[settings]
# the following characters are these which a "word" can contains, see documentation
-wordchars=_#&abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789
+wordchars=@_abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789
# if only single comment char is supported like # in this file, leave comment_close blank
comment_open=//
@@ -50,5 +50,5 @@
# %f will be replaced by the complete filename
# %e will be replaced by the filename without extension
# (use only one of it at one time)
-compiler=ferite -c "%f"
+compiler=ferite -vc "%f"
run_cmd=ferite "%f"
Modified: trunk/src/msgwindow.c
===================================================================
--- trunk/ChangeLog 2006-08-28 16:27:16 UTC (rev 771)
+++ trunk/ChangeLog 2006-08-29 16:11:55 UTC (rev 772)
@@ -1,3 +1,8 @@
+2006-08-29 Enrico Tröger <enrico.troeger(a)uvena.de>
+
+ * src/sci_cb.c: Added auto completion for LaTeX command "begin".
+
+
2006-08-28 Enrico Tröger <enrico.troeger(a)uvena.de>
* geany.glade, src/interface.c: Fixed typo in a tooltip text.
Modified: trunk/src/sci_cb.c
===================================================================
--- trunk/src/sci_cb.c 2006-08-28 16:27:16 UTC (rev 771)
+++ trunk/src/sci_cb.c 2006-08-29 16:11:55 UTC (rev 772)
@@ -614,12 +614,10 @@
void sci_cb_auto_latex(ScintillaObject *sci, gint pos, gint idx)
{
- // currently disabled
-#if 0
if (sci_get_char_at(sci, pos - 2) == '}')
{
gchar *eol, *buf, *construct;
- gchar env[30]; /// FIXME are 30 chars enough?
+ gchar env[50];
gint line = sci_get_line_from_position(sci, pos - 2);
gint line_len = sci_get_line_length(sci, line);
gint i, start;
@@ -629,21 +627,35 @@
sci_get_line(sci, line, buf);
// get to the first non-blank char (some kind of ltrim())
- i = start = 0;
- while (isspace(buf[i++])) start++;
+ start = 0;
+ //while (isspace(buf[i++])) start++;
+ while (isspace(buf[start])) start++;
// check for begin
if (strncmp(buf + start, "\\begin", 6) == 0)
{
- // goto through the line and get the environment, begin at first non-blank char (= start)
- for (i = start; i < line_len; i++)
+ gchar full_cmd[15];
+ gint j = 0;
+
+ // take also "\begingroup" (or whatever there can be) and append "\endgroup" and so on.
+ i = start + 6;
+ while (buf[i] != '{' && j < (sizeof(full_cmd) - 1))
+ { // copy all between "\begin" and "{" to full_cmd
+ full_cmd[j] = buf[i];
+ i++;
+ j++;
+ }
+ full_cmd[j] = '\0';
+
+ // go through the line and get the environment
+ for (i = start + j; i < line_len; i++)
{
if (buf[i] == '{')
{
- gint j = 0;
+ j = 0;
i++;
- while (buf[i] != '}')
- { // this could be done in a shorter way, but so it resists readable ;-)
+ while (buf[i] != '}' && j < (sizeof(env) - 1))
+ { // this could be done in a shorter way, but so it remains readable ;-)
env[j] = buf[i];
j++;
i++;
@@ -657,7 +669,7 @@
if (doc_list[idx].use_auto_indention) sci_cb_get_indent(sci, pos, TRUE);
eol = g_strconcat(utils_get_eol_char(idx), indent, NULL);
- construct = g_strdup_printf("%s\\end{%s}", eol, env);
+ construct = g_strdup_printf("%s\\end%s{%s}", eol, full_cmd, env);
SSM(sci, SCI_INSERTTEXT, pos, (sptr_t) construct);
sci_goto_pos(sci, pos + 1, TRUE);
@@ -670,7 +682,6 @@
return;
}
}
-#endif
}
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
--- trunk/src/msgwindow.c 2006-08-30 18:53:45 UTC (rev 774)
+++ trunk/src/msgwindow.c 2006-08-31 18:25:57 UTC (rev 775)
@@ -417,11 +417,22 @@
}
case GEANY_FILETYPES_FERITE:
{
- // Error: Parse Error: on line 5 in "/misc/tmp/testfiles_geany/hello.fe"
- pattern = " \"";
- field_min_len = 10;
- field_idx_line = 5;
- field_idx_file = 8;
+ // Error: Parse Error: on line 5 in "/tmp/hello.fe"
+ // Error: Compile Error: on line 24, in /test/class.fe
+ if (strncmp(string, "Error: Compile Error", 20) == 0)
+ {
+ pattern = " ";
+ field_min_len = 8;
+ field_idx_line = 5;
+ field_idx_file = 7;
+ }
+ else
+ {
+ pattern = " \"";
+ field_min_len = 10;
+ field_idx_line = 5;
+ field_idx_file = 8;
+ }
break;
}
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
Revision: 772
Author: eht16
Date: 2006-08-29 09:11:55 -0700 (Tue, 29 Aug 2006)
ViewCVS: http://svn.sourceforge.net/geany/?rev=772&view=rev
Log Message:
-----------
Added auto completion for LaTeX command "begin".
Modified Paths:
--------------
trunk/ChangeLog
trunk/src/sci_cb.c
Modified: trunk/ChangeLog
===================================================================